@@ -15,16 +15,19 @@
 #     HomePage: http://www.vimer.cn
 #
 #      Created: 2012-07-09 17:23:51
-#      Version: 0.2.0
 #      History:
 #               0.0.1 | dantezhu | 2012-07-09 17:23:51 | initialization
 #               0.1   | dantezhu | 2012-08-30 22:54:33 | 正式版本
-#               0.2.0 | John Doe | 2012-10-22 21:53:14 | 优化为实例的方式
+#               0.2.0 | dantezhu | 2012-10-22 21:53:14 | 优化为实例的方式
+#               0.2.3 | dantezhu | 2012-11-20 11:13:22 | 增加no cache
+#               0.2.4 | dantezhu | 2012-11-30 10:58:13 | content-type
+#               0.2.5 | dantezhu | 2012-12-04 11:41:15 | defaults不需要，缺少params报异常
+#               0.2.6 | dantezhu | 2013-07-15 16:44:12 | fix bug，当params中有为0的参数时，不正常
 #
 #=============================================================================
 '''
 
-__version__ = (0, 2, 0)
+__version__ = (0, 2, 6)
 
 from flask import Response
 from flask import render_template_string, json
@@ -70,13 +73,6 @@ var flask_util = function() {
             return '';
         }
         var rule = url_map[endpoint]['rule'];
-        var defaults = url_map[endpoint]['defaults'];
-
-        for(var k in defaults) {
-            if (!(k in params)) {
-                params[k] = defaults[k];
-            }
-        }
 
         var used_params = {};
 
@@ -84,18 +80,18 @@ var flask_util = function() {
         var rex = /\<\s*(\w+:)*(\w+)\s*\>/ig;
 
         var path = rule.replace(rex, function(_i, _0, _1) {
-            if (params[_1]) {
+            if (params.hasOwnProperty(_1)) {
                 used_params[_1] = params[_1];
                 return url_encode(params[_1]);
             } else {
-                return '';
+                throw(_1 + ' does not exist in params');
             }
         });
 
         var query_string = '';
 
         for(var k in params) {
-            if (used_params[k]) {
+            if (used_params.hasOwnProperty(k)) {
                 continue;
             }
 
@@ -141,7 +137,7 @@ class FlaskUtilJs(object):
         安装到app上
         """
         if self._app is not None:
-            raise Exception('Flask-Admin is already associated with an application.')
+            raise Exception('flask_util_js is already associated with an application.')
 
         self._app = app
             
@@ -158,7 +154,6 @@ class FlaskUtilJs(object):
             for k,v in org_url_map.items():
                 url_map[k] = dict(
                     rule=v[0].rule,
-                    defaults=v[0].defaults or {},
                     )
 
             json_url_map = json.dumps(url_map, indent=4, ensure_ascii=False)
@@ -168,7 +163,13 @@ class FlaskUtilJs(object):
                 json_url_map=json_url_map
                 )
 
-            return Response(rv, content_type='application/x-javascript')
+            return Response(
+                rv,
+                content_type='text/javascript; charset=UTF-8',
+                headers={
+                    'Cache-Control':'no-cache',
+                }
+            )
         
         # 最后把数据写到实例里
         self._path = path
